summaryrefslogtreecommitdiff
path: root/libavcodec/ituh263dec.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/ituh263dec.c')
-rw-r--r--libavcodec/ituh263dec.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/libavcodec/ituh263dec.c b/libavcodec/ituh263dec.c
index b9189b2e4d..9199f5c28d 100644
--- a/libavcodec/ituh263dec.c
+++ b/libavcodec/ituh263dec.c
@@ -1,7 +1,7 @@
/*
* ITU H263 bitstream decoder
* Copyright (c) 2000,2001 Fabrice Bellard
- * H263+ support.
+ * H.263+ support.
* Copyright (c) 2001 Juan J. Sierralta P
* Copyright (c) 2002-2004 Michael Niedermayer <michaelni@gmx.at>
*
@@ -24,7 +24,7 @@
/**
* @file
- * h263 decoder.
+ * H.263 decoder.
*/
#include <limits.h>
@@ -298,7 +298,7 @@ int ff_h263_decode_motion(MpegEncContext * s, int pred, int f_code)
if (!s->h263_long_vectors) {
val = sign_extend(val, 5 + f_code);
} else {
/* horrible h263 long vector mode */
if (pred < -31 && val < -63)
val += 64;
if (pred > 32 && val > 63)
@@ -866,7 +866,7 @@ end:
return SLICE_OK;
}
/* most is hardcoded. should extend to handle all h263 streams */
int ff_h263_decode_picture_header(MpegEncContext *s)
{
int format, width, height, i, ret;
@@ -900,8 +900,8 @@ int ff_h263_decode_picture_header(MpegEncContext *s)
return -1;
}
if (get_bits1(&s->gb) != 0) {
- av_log(s->avctx, AV_LOG_ERROR, "Bad H263 id\n");
- return -1; /* h263 id */
+ av_log(s->avctx, AV_LOG_ERROR, "Bad H.263 id\n");
+ return -1; /* H.263 id */
}
skip_bits1(&s->gb); /* split screen off */
skip_bits1(&s->gb); /* camera off */
@@ -926,7 +926,7 @@ int ff_h263_decode_picture_header(MpegEncContext *s)
s->h263_long_vectors = get_bits1(&s->gb);
if (get_bits1(&s->gb) != 0) {
- av_log(s->avctx, AV_LOG_ERROR, "H263 SAC not supported\n");
+ av_log(s->avctx, AV_LOG_ERROR, "H.263 SAC not supported\n");
return -1; /* SAC: off */
}
s->obmc= get_bits1(&s->gb); /* Advanced prediction mode */
@@ -1017,7 +1017,7 @@ int ff_h263_decode_picture_header(MpegEncContext *s)
height = get_bits(&s->gb, 9) * 4;
ff_dlog(s->avctx, "\nH.263+ Custom picture: %dx%d\n",width,height);
if (s->aspect_ratio_info == FF_ASPECT_EXTENDED) {
- /* aspected dimensions */
+ /* expected dimensions */
s->avctx->sample_aspect_ratio.num= get_bits(&s->gb, 8);
s->avctx->sample_aspect_ratio.den= get_bits(&s->gb, 8);
}else{
@@ -1,7 +1,7 @@
/*
- * ITU H263 bitstream decoder
+ * ITU H.263 bitstream decoder
* Copyright (c) 2000,2001 Fabrice Bellard
@@ -298,7 +298,7 @@ int ff_h263_decode_motion(MpegEncContext * s, int pred, int f_code)
val = sign_extend(val, 5 + f_code);
} else {
- /* horrible h263 long vector mode */
+ /* horrible H.263 long vector mode */
if (pred < -31 && val < -63)
val += 64;
@@ -866,7 +866,7 @@ end:
return SLICE_OK;
}
-/* most is hardcoded. should extend to handle all h263 streams */
+/* Most is hardcoded; should extend to handle all H.263 streams. */
int ff_h263_decode_picture_header(MpegEncContext *s)
{